@@ -31,11 +31,12 @@ describe 'gnocchi::api' do
       )
     end
 
-    it 'configures keystone authentication middleware' do
+    it 'configures gnocchi-api' do
       is_expected.to contain_gnocchi_config('api/host').with_value( params[:host] )
       is_expected.to contain_gnocchi_config('api/port').with_value( params[:port] )
       is_expected.to contain_gnocchi_config('api/max_limit').with_value( params[:max_limit] )
       is_expected.to contain_gnocchi_config('api/workers').with_value('2')
+      is_expected.to contain_gnocchi_config('oslo_middleware/enable_proxy_headers_parsing').with_value('<SERVICE DEFAULT>')
     end
 
     [{:enabled => true}, {:enabled => false}].each do |param_hash|
@@ -141,6 +142,15 @@ describe 'gnocchi::api' do
         is_expected.to contain_gnocchi_api_paste_ini('pipeline:main/pipeline').with_value('gnocchi+auth');
       end
     end
+
+    context 'with enable_proxy_headers_parsing' do
+      before do
+        params.merge!({:enable_proxy_headers_parsing => true })
+      end
+
+      it { is_expected.to contain_gnocchi_config('oslo_middleware/enable_proxy_headers_parsing').with_value(true) }
+    end
+
   end
 
   on_supported_os({
